@@ -3,7 +3,7 @@ package Sah::Schema::aohos;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Collection'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of (defined-)hash-of-(defined-)strings',
@@ -41,7 +41,33 @@ Sah::Schema::aohos - Array of (defined-)hash-of-(defined-)strings
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schema::aohos (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+This document describes version 0.004 of Sah::Schema::aohos (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ "a"  # INVALID
+
+ []  # valid
+
+ {}  # INVALID
+
+ [undef]  # INVALID
+
+ ["a"]  # INVALID
+
+ [[]]  # INVALID
+
+ [{}]  # valid
+
+ [{},{k=>"a"}]  # valid
+
+ [{},{k=>[]}]  # INVALID
+
+ [{},{k=>{}}]  # INVALID
+
+ [{},{k=>undef}]  # INVALID
 
 =head1 DESCRIPTION
 
