@@ -3,7 +3,7 @@ package Sah::Schema::aoms;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-02'; # DATE
 our $DIST = 'Sah-Schemas-Collection'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of maybe-strings',
@@ -37,7 +37,25 @@ Sah::Schema::aoms - Array of maybe-strings
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schema::aoms (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+This document describes version 0.004 of Sah::Schema::aoms (from Perl distribution Sah-Schemas-Collection), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ "a"  # INVALID
+
+ []  # valid
+
+ {}  # INVALID
+
+ ["a"]  # valid
+
+ [undef]  # valid
+
+ ["a",[]]  # INVALID
+
+ [["a"]]  # INVALID
 
 =head1 DESCRIPTION
 
